@@ -110,6 +110,9 @@ xfce_shortcuts_grabber_class_init (XfceShortcutsGrabberClass *klass)
 static void
 xfce_shortcuts_grabber_init (XfceShortcutsGrabber *grabber)
 {
+  GdkDisplay      *display;
+  GdkKeymap       *keymap;
+
   grabber->priv = XFCE_SHORTCUTS_GRABBER_GET_PRIVATE (grabber);
   grabber->priv->keys = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 
@@ -118,7 +121,9 @@ xfce_shortcuts_grabber_init (XfceShortcutsGrabber *grabber)
    * mapped because the modmap is not updated. The following function
    * updates it.
    */
-  (void) gdk_keymap_have_bidi_layouts (gdk_keymap_get_default ());
+  display = gdk_display_get_default ();
+  keymap = gdk_keymap_get_for_display (display);
+  (void) gdk_keymap_have_bidi_layouts (keymap);
 }
 
 
@@ -131,12 +136,11 @@ xfce_shortcuts_grabber_constructed (GObject *object)
 
   XfceShortcutsGrabber *grabber = XFCE_SHORTCUTS_GRABBER (object);
 
-  keymap = gdk_keymap_get_default ();
+  display = gdk_display_get_default ();
+  keymap = gdk_keymap_get_for_display (display);
   g_signal_connect (keymap, "keys-changed", G_CALLBACK (xfce_shortcuts_grabber_keys_changed),
                     grabber);
 
-  display = gdk_display_get_default ();
-
   /* Flush events before adding the event filter */
   XAllowEvents (GDK_DISPLAY_XDISPLAY (display), AsyncBoth, CurrentTime);
 
@@ -237,12 +241,8 @@ xfce_shortcuts_grabber_grab (XfceShortcutsGrabber *grabber,
   g_return_if_fail (key != NULL);
 
   display = gdk_display_get_default ();
-#if GTK_CHECK_VERSION (3, 10, 0)
   screens = 1;
-#else
-  screens = gdk_display_get_n_screens (display);
-#endif
-  keymap = gdk_keymap_get_default ();
+  keymap = gdk_keymap_get_for_display (display);
 
   /* Map virtual modifiers to non-virtual modifiers */
   modifiers = key->modifiers;
@@ -317,15 +317,9 @@ xfce_shortcuts_grabber_grab (XfceShortcutsGrabber *grabber,
             numlock_modifier | GDK_MOD2_MASK | GDK_LOCK_MASK | GDK_MOD5_MASK,
           };
 
-#if GTK_CHECK_VERSION (3, 0, 0)
           /* Retrieve the root window of the screen */
-          root_window = GDK_WINDOW_XID (gdk_screen_get_root_window (gdk_display_get_screen (display, j)));
-#else
-          /* Retrieve the root window of the screen */
-          root_window = GDK_WINDOW_XWINDOW (gdk_screen_get_root_window (gdk_display_get_screen (display, j)));
-#endif
-
-          gdk_error_trap_push ();
+          root_window = GDK_WINDOW_XID (gdk_screen_get_root_window (gdk_display_get_default_screen (display)));
+          gdk_x11_display_error_trap_push (display);
 
           for (k = 0; k < G_N_ELEMENTS (mod_masks); k++)
             {
@@ -345,9 +339,9 @@ xfce_shortcuts_grabber_grab (XfceShortcutsGrabber *grabber,
                             root_window);
             }
 
-          gdk_flush ();
+          gdk_display_flush (display);
 
-          if (gdk_error_trap_pop ())
+          if (gdk_x11_display_error_trap_pop (display))
             {
               if (grab)
                 TRACE ("Failed to grab");
@@ -404,6 +398,7 @@ xfce_shortcuts_grabber_event_filter (GdkXEvent            *gdk_xevent,
   struct EventKeyFindContext  context;
   GdkKeymap                  *keymap;
   GdkModifierType             consumed, modifiers;
+  GdkDisplay                 *display;
   XEvent                     *xevent;
   guint                       keyval, mod_mask;
   gchar                      *raw_shortcut_name;
@@ -421,8 +416,9 @@ xfce_shortcuts_grabber_event_filter (GdkXEvent            *gdk_xevent,
   timestamp = xevent->xkey.time;
 
   /* Get the keyboard state */
-  gdk_error_trap_push ();
-  keymap = gdk_keymap_get_default ();
+  display = gdk_display_get_default ();
+  gdk_x11_display_error_trap_push (display);
+  keymap = gdk_keymap_get_for_display (display);
   mod_mask = gtk_accelerator_get_default_mod_mask ();
   modifiers = xevent->xkey.state;
 
@@ -483,13 +479,8 @@ xfce_shortcuts_grabber_event_filter (GdkXEvent            *gdk_xevent,
     g_signal_emit_by_name (grabber, "shortcut-activated",
                            context.result, timestamp);
 
-  gdk_flush ();
-
-#if GTK_CHECK_VERSION (3, 0, 0)
-  gdk_error_trap_pop_ignored ();
-#else
-  gdk_error_trap_pop ();
-#endif
+  gdk_display_flush (display);
+  gdk_x11_display_error_trap_pop_ignored (display);
 
   return GDK_FILTER_CONTINUE;
 }
