@@ -32,6 +32,10 @@
 #include "translators.h"
 #include "about-dialog-ui.h"
 
+#ifdef HAVE_GLIBTOP
+#include "system-info.h"
+#endif
+
 #define MARGIN 20
 
 
@@ -54,6 +58,57 @@ static GOptionEntry opt_entries[] =
 };
 
 
+#ifdef HAVE_GLIBTOP
+static void
+xfce_about_system (GtkBuilder *builder)
+{
+  GObject *label;
+  GObject *vendor_info;
+  glibtop_mem mem;
+  const glibtop_sysinfo *info;
+  g_autofree char *device_text = NULL;
+  g_autofree char *cpu_text = NULL;
+  g_autofree char *memory_text = NULL;
+  g_autofree char *os_name_text = NULL;
+  g_autofree char *os_type_text = NULL;
+
+  label = gtk_builder_get_object (builder, "device");
+  device_text = get_system_info (DEVICE_NAME);
+  gtk_label_set_text (GTK_LABEL (label), device_text ? device_text : "");
+
+  label = gtk_builder_get_object (builder, "osname");
+  os_name_text = get_os_name ();
+  gtk_label_set_text (GTK_LABEL (label), os_name_text ? os_name_text : "");
+
+  label = gtk_builder_get_object (builder, "ostype");
+  os_type_text = get_system_info (ARCH);
+  gtk_label_set_text (GTK_LABEL (label), os_type_text ? os_type_text : "");
+
+  label = gtk_builder_get_object (builder, "xfce-version");
+  gtk_label_set_text (GTK_LABEL (label), xfce_version_string ());
+
+  label = gtk_builder_get_object (builder, "vendor-info");
+  vendor_info = gtk_builder_get_object (builder, "vendor-info-label");
+#ifdef VENDOR_INFO
+  gtk_label_set_text (GTK_LABEL (label), VENDOR_INFO);
+#else
+  gtk_widget_hide (GTK_WIDGET (vendor_info));
+  gtk_widget_hide (GTK_WIDGET (label));
+#endif
+
+  label = gtk_builder_get_object (builder, "cpu");
+  info = glibtop_get_sysinfo ();
+  cpu_text = get_cpu_info (info);
+  gtk_label_set_markup (GTK_LABEL (label), cpu_text ? cpu_text : "");
+
+  label = gtk_builder_get_object (builder, "memory");
+  glibtop_get_mem (&mem);
+  memory_text = g_format_size_full (mem.total, G_FORMAT_SIZE_IEC_UNITS);
+  gtk_label_set_text (GTK_LABEL (label), memory_text ? memory_text : "");
+}
+#endif
+
+
 
 static void
 xfce_about_about (GtkTextBuffer *buffer)
@@ -494,6 +549,13 @@ main (gint    argc,
   xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (dialog), version);
   g_free (version);
 
+#ifdef HAVE_GLIBTOP
+  xfce_about_system (builder);
+#else
+  // Hide system tab
+  gtk_notebook_remove_page (GTK_NOTEBOOK (gtk_builder_get_object (builder, "notebook")), 0);
+#endif
+
   object = gtk_builder_get_object (builder, "about-buffer");
   xfce_about_about (GTK_TEXT_BUFFER (object));
 
